@@ -594,12 +594,24 @@ def test_remove_colinear_vertices():
     pts_1 = (Point3D(0, 0), Point3D(2, 0), Point3D(2, 2), Point3D(0, 2))
     pts_2 = (Point3D(0, 0), Point3D(1, 0), Point3D(2, 0), Point3D(2, 2),
              Point3D(0, 2))
+    pts_3 = (Point3D(0, 0), Point3D(2, 0), Point3D(2, 2),
+             Point3D(0, 2), Point3D(0, 2))
+    pts_4 = (Point3D (24.21, 23.22, 8.00), Point3D (24.21, 23.22, 11.60),
+             Point3D (24.61, 23.22, 11.60), Point3D (27.85, 23.22, 11.60),
+             Point3D (30.28, 23.22, 11.60), Point3D (30.28, 23.22, 0.00),
+             Point3D (27.85, 23.22, 0.00), Point3D (27.85, 23.22, 4.00),
+             Point3D (27.85, 23.22, 8.00), Point3D (27.85, 23.22, 8.00),
+             Point3D (24.61, 23.22, 8.00), Point3D (24.61, 23.22, 8.00))
     plane_1 = Plane(Vector3D(0, 0, 1))
     face_1 = Face3D(pts_1, plane_1)
     face_2 = Face3D(pts_2, plane_1)
+    face_3 = Face3D(pts_3, plane_1)
+    face_4 = Face3D(pts_4)
 
     assert len(face_1.remove_colinear_vertices(0.0001).vertices) == 4
     assert len(face_2.remove_colinear_vertices(0.0001).vertices) == 4
+    assert len(face_3.remove_colinear_vertices(0.0001).vertices) == 4
+    assert len(face_4.remove_colinear_vertices(0.0001).vertices) == 6
 
 
 def test_remove_colinear_vertices_custom():
@@ -670,6 +682,15 @@ def test_triangulated_mesh_with_many_holes():
             pytest.approx(face_geo.area, rel=1e-3)
 
 
+def test_triangulated_mesh_edge_case():
+    """Test triangulation properties of a Face3D triggering a zero division."""
+    geo_file = './tests/json/edge_case_face.json'
+    with open(geo_file, 'r') as fp:
+        geo_dict = json.load(fp)
+    face_geo = Face3D.from_dict(geo_dict)
+    assert face_geo.triangulated_mesh3d.area != 0
+
+
 def test_check_planar():
     """Test the check_planar method of Face3D."""
     pts_1 = (Point3D(0, 0, 2), Point3D(2, 0, 2), Point3D(2, 2, 2), Point3D(0, 2, 2))
